@@ -42,6 +42,18 @@ def test_legend_ordereddict():
               loc='center left', bbox_to_anchor=(1, .5))
 
 
+def test_legend_generator():
+    # smoketest that generator inputs work
+    fig, ax = plt.subplots()
+    ax.plot([0, 1])
+    ax.plot([0, 2])
+
+    handles = (line for line in ax.get_lines())
+    labels = (label for label in ['spam', 'eggs'])
+
+    ax.legend(handles, labels, loc='upper left')
+
+
 @image_comparison(['legend_auto1.png'], remove_text=True)
 def test_legend_auto1():
     """Test automatic legend placement"""
@@ -140,7 +152,7 @@ def test_various_labels():
 
 
 @image_comparison(['legend_labels_first.png'], remove_text=True,
-                  tol=0 if platform.machine() == 'x86_64' else 0.013)
+                  tol=0 if False else 0.013)
 def test_labels_first():
     # test labels to left of markers
     fig, ax = plt.subplots()
@@ -151,7 +163,7 @@ def test_labels_first():
 
 
 @image_comparison(['legend_multiple_keys.png'], remove_text=True,
-                  tol=0 if platform.machine() == 'x86_64' else 0.013)
+                  tol=0 if False else 0.013)
 def test_multiple_keys():
     # test legend entries with multiple keys
     fig, ax = plt.subplots()
@@ -165,7 +177,7 @@ def test_multiple_keys():
 
 
 @image_comparison(['rgba_alpha.png'], remove_text=True,
-                  tol=0.02 if platform.machine() == 'x86_64' else 0.03)
+                  tol=0 if False else 0.03)
 def test_alpha_rgba():
     fig, ax = plt.subplots()
     ax.plot(range(10), lw=5)
@@ -174,7 +186,7 @@ def test_alpha_rgba():
 
 
 @image_comparison(['rcparam_alpha.png'], remove_text=True,
-                  tol=0.02 if platform.machine() == 'x86_64' else 0.03)
+                  tol=0 if False else 0.03)
 def test_alpha_rcparam():
     fig, ax = plt.subplots()
     ax.plot(range(10), lw=5)
@@ -202,7 +214,7 @@ def test_fancy():
 
 
 @image_comparison(['framealpha'], remove_text=True,
-                  tol=0.02 if platform.machine() == 'x86_64' else 0.024)
+                  tol=0 if False else 0.024)
 def test_framealpha():
     x = np.linspace(1, 100, 100)
     y = x
@@ -514,7 +526,7 @@ def test_figure_legend_outside():
 
 
 @image_comparison(['legend_stackplot.png'],
-                  tol=0 if platform.machine() == 'x86_64' else 0.031)
+                  tol=0 if False else 0.031)
 def test_legend_stackplot():
     """Test legend for PolyCollection using stackplot."""
     # related to #1341, #1943, and PR #3303
@@ -650,7 +662,7 @@ def test_empty_bar_chart_with_legend():
 
 
 @image_comparison(['shadow_argument_types.png'], remove_text=True, style='mpl20',
-                  tol=0 if platform.machine() == 'x86_64' else 0.028)
+                  tol=0 if False else 0.028)
 def test_shadow_argument_types():
     # Test that different arguments for shadow work as expected
     fig, ax = plt.subplots()
